Downloads multiple resources from a dataset on the NHS Open Data platform by dataset name, with optional row limits and context columns.
get_dataset(
dataset_name,
max_resources = NULL,
rows = NULL,
row_filters = NULL,
col_select = NULL,
include_context = FALSE
)Name of the dataset as found on the NHS Open Data platform (character).
(optional) The maximum number of resources to return (integer). If not set, all resources are returned.
(optional) Maximum number of rows to return (integer).
(optional) A named list or vector specifying values of columns/fields to keep (e.g., list(Date = 20220216, Sex = "Female")).
(optional) A character vector containing the names of desired columns/fields (e.g., c("Date", "Sex")).
(optional) If TRUE, additional information about the resource will be added as columns to the data, including the resource ID, the resource name, the creation date, and the last modified/updated date.
A tibble with the data.
get_resource() for downloading a single resource from a dataset.
if (FALSE) { # \dontrun{
get_dataset("gp-practice-populations", max_resources = 2, rows = 10)
} # }