list_datasets() shows all of the datasets hosted on the PHS Open Data
Platform.
list_datasets()A tibble.
list_datasets() has been superseded by list_resources().
While list_datasets() only returns a list of dataset packages,
list_resources() provides a more comprehensive and flexible
interface for exploring the PHS Open Data platform. It returns both
datasets and their associated resources in a single tibble, and
supports filtering by dataset titles or resource names.
head(list_datasets())
#> # A tibble: 6 × 1
#> name
#> <chr>
#> 1 18-weeks-referral-to-treatment
#> 2 27-30-month-review-statistics
#> 3 alcohol-related-hospital-statistics-scotland
#> 4 allied-health-professionals-musculoskeletal-waiting-times
#> 5 allied-health-professional-vacancies
#> 6 annual-cancer-incidence