Learn R Programming

phsopendata (version 1.1.0)

list_datasets: Lists all available datasets

Description

list_datasets() shows all of the datasets hosted on the PHS Open Data Platform.

Usage

list_datasets()

Arguments

Value

A tibble.

Lifecycle

[Superseded]

list_datasets() has been superseded by list_resources(). While list_datasets() only returns a list of dataset packages, list_resources() provides a more comprehensive and flexible interface for exploring the PHS Open Data platform. It returns both datasets and their associated resources in a single tibble, and supports filtering by dataset titles or resource names.

See Also

list_resources()

Examples

Run this code
head(list_datasets())

Run the code above in your browser using DataLab