R/list_resources.R
list_resources.RdProvides an overview of all resources available from opendata.nhs.scot, with the option to limit results based on both dataset and resource names. The returned tibble can be used to look-up dataset and resource ids, and is useful for exploring the available data sets.
list_resources(
dataset_contains = NULL,
resource_contains = NULL,
dataset_name = lifecycle::deprecated()
)A character string containing an expression to be used as search criteria against the dataset name.
A character string containing a regular expression to be matched against available resource names.
Deprecated. Use dataset_contains instead.
A tibble containing details of all available datasets and
resources, or those containing the string specified in the
dataset_contains and resource_contains arguments.
list_resources()
#> # A tibble: 1,131 × 7
#> resource_name resource_id dataset_name dataset_title dataset_id url
#> <chr> <chr> <chr> <chr> <chr> <chr>
#> 1 Demographics 6abbf8e4-e… monthly-acc… Monthly A&E … 997acaa5-… http…
#> 2 Monthly Accident and… 37ba17b1-c… monthly-acc… Monthly A&E … 997acaa5-… http…
#> 3 Referral Source 235407ca-1… monthly-acc… Monthly A&E … 997acaa5-… http…
#> 4 Discharge c4622324-f… monthly-acc… Monthly A&E … 997acaa5-… http…
#> 5 When 022c3b27-6… monthly-acc… Monthly A&E … 997acaa5-… http…
#> 6 Multiple Attendances 0ca3b959-b… monthly-acc… Monthly A&E … 997acaa5-… http…
#> 7 Multiple Attendances… 7f2e9288-5… monthly-acc… Monthly A&E … 997acaa5-… http…
#> 8 ARCHIVE - Monthly Ac… 2a4adc0a-e… monthly-acc… Monthly A&E … 997acaa5-… http…
#> 9 Primary Care Out of … 3e86b6fb-2… primary-car… Primary Care… 4d682149-… http…
#> 10 Primary Care Out of … 1427474e-f… primary-car… Primary Care… 4d682149-… http…
#> # ℹ 1,121 more rows
#> # ℹ 1 more variable: last_modified <dttm>
list_resources(dataset_contains = "standard-populations")
#> # A tibble: 4 × 7
#> resource_name resource_id dataset_name dataset_title dataset_id url
#> <chr> <chr> <chr> <chr> <chr> <chr>
#> 1 European Standard Pop… edee9731-d… standard-po… Standard Pop… 4dd86111-… http…
#> 2 European Standard Pop… 29ce4cda-a… standard-po… Standard Pop… 4dd86111-… http…
#> 3 World Standard Popula… e27533df-a… standard-po… Standard Pop… 4dd86111-… http…
#> 4 World Standard Popula… 2f493d21-f… standard-po… Standard Pop… 4dd86111-… http…
#> # ℹ 1 more variable: last_modified <dttm>
list_resources(
dataset_contains = "standard-populations", resource_contains = "European"
)
#> # A tibble: 2 × 7
#> resource_name resource_id dataset_name dataset_title dataset_id url
#> <chr> <chr> <chr> <chr> <chr> <chr>
#> 1 European Standard Pop… edee9731-d… standard-po… Standard Pop… 4dd86111-… http…
#> 2 European Standard Pop… 29ce4cda-a… standard-po… Standard Pop… 4dd86111-… http…
#> # ℹ 1 more variable: last_modified <dttm>