R/list_resources.R
list_resources.RdProvides an overview of all resources available from opendata.nhs.scot, with the option to limit results based on both dataset and resource names. The returned tibble can be used to look-up dataset and resource ids, and is useful for exploring the available data sets.
list_resources(
dataset_contains = NULL,
resource_contains = NULL,
dataset_name = lifecycle::deprecated()
)A character string containing an expression to be used as search criteria against the dataset name.
A character string containing a regular expression to be matched against available resource names.
Deprecated. Use dataset_contains instead.
A tibble containing details of all available datasets and
resources, or those containing the string specified in the
dataset_contains and resource_contains arguments.
list_resources()
#> # A tibble: 1,115 × 7
#> resource_name resource_id dataset_name dataset_title dataset_id url
#> <chr> <chr> <chr> <chr> <chr> <chr>
#> 1 Delayed Discharge Be… fd354e4b-6… delayed-dis… Delayed Disc… 52591cba-… http…
#> 2 Delayed Discharge Be… 513d2d71-c… delayed-dis… Delayed Disc… 52591cba-… http…
#> 3 Census Delays by Hea… 49ca8a39-7… delayed-dis… Delayed Disc… 52591cba-… http…
#> 4 Census Delays by Cou… 0924cb38-2… delayed-dis… Delayed Disc… 52591cba-… http…
#> 5 Delayed Discharge Be… b7276489-6… delayed-dis… Delayed Disc… 52591cba-… http…
#> 6 Delayed Discharge Be… 2a07d2e2-f… delayed-dis… Delayed Disc… 52591cba-… http…
#> 7 GP Practices and Lis… e572d9fd-c… gp-practice… GP Practice … f23655c3-… http…
#> 8 GP Practices and Lis… ceddbf27-0… gp-practice… GP Practice … f23655c3-… http…
#> 9 GP Practices and Lis… 47557411-7… gp-practice… GP Practice … f23655c3-… http…
#> 10 GP Practices and Lis… 30b06220-1… gp-practice… GP Practice … f23655c3-… http…
#> # ℹ 1,105 more rows
#> # ℹ 1 more variable: last_modified <dttm>
list_resources(dataset_contains = "standard-populations")
#> # A tibble: 4 × 7
#> resource_name resource_id dataset_name dataset_title dataset_id url
#> <chr> <chr> <chr> <chr> <chr> <chr>
#> 1 European Standard Pop… edee9731-d… standard-po… Standard Pop… 4dd86111-… http…
#> 2 European Standard Pop… 29ce4cda-a… standard-po… Standard Pop… 4dd86111-… http…
#> 3 World Standard Popula… e27533df-a… standard-po… Standard Pop… 4dd86111-… http…
#> 4 World Standard Popula… 2f493d21-f… standard-po… Standard Pop… 4dd86111-… http…
#> # ℹ 1 more variable: last_modified <dttm>
list_resources(
dataset_contains = "standard-populations", resource_contains = "European"
)
#> # A tibble: 2 × 7
#> resource_name resource_id dataset_name dataset_title dataset_id url
#> <chr> <chr> <chr> <chr> <chr> <chr>
#> 1 European Standard Pop… edee9731-d… standard-po… Standard Pop… 4dd86111-… http…
#> 2 European Standard Pop… 29ce4cda-a… standard-po… Standard Pop… 4dd86111-… http…
#> # ℹ 1 more variable: last_modified <dttm>