list_resources: Provides an overview of all resources available on the Open Data platform.
Description
Provides an overview of all resources available from
opendata.nhs.scot, with the option to limit results based on both dataset
and resource names. The returned tibble can be used to look-up dataset
and resource ids, and is useful for exploring the available data sets.
A tibble containing details of all available datasets and
resources, or those containing the string specified in the
dataset_contains and resource_contains arguments.
Arguments
dataset_contains
A character string containing an expression to be
used as search criteria against the dataset name.
resource_contains
A character string containing a regular expression
to be matched against available resource names.